# Structured data validation for AROS output files.

[![Tests](https://github.com/jdiez/structured_data_validation/workflows/Tests/badge.svg)](https://github.com/jdiez/structured_data_validation/actions?workflow=Tests)
[![PyPI](https://img.shields.io/pypi/v/structured_data_validation.svg)](https://pypi.org/project/structured_data_validation/)

Python package for the validation of AROS [semi]structured data using pydantic models.

[More coming soon]
